==> cenote_0.8.4_20071018.zip: cenote/setup/index3.php <==
<?php
if(file_exists("../configuration.php")){
	header("Location: ./index.php");
}
?>

<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<meta http-equiv="Content-Type" content="text/html; charset=UTF-8" />
<title>CENOTE SETUP TOOL(SITE CONFIGURATION)</title>
<style type="text/css">
<!--
body {
	margin-left: 0px;
	margin-top: 0px;
	margin-right: 0px;
	margin-bottom: 0px;
}
.style1 {
	font-size: 24px;
	font-style: italic;
	text-align: center;
}
.style2 {font-size: 14px; font-style: bold; text-align: left;}

.red {color: #FF0000}

-->
</style>
</head>
<?php
session_name("CENOTE_SETUP");
session_cache_limiter('private, must-revalidate');
session_start();

$mes = "";

$site_name = isset($_POST['site_name']) ? trim($_POST['site_name']) : "";
$site_url  = isset($_POST['site_url']) ? trim($_POST['site_url']) : "http://";
$img_dir   = isset($_POST['img_dir']) ? trim($_POST['img_dir']) : "/images/";
$site_sess = isset($_POST['site_sess']) ? trim($_POST['site_sess']) : "cenote";
$site_encode = isset($_POST['site_encode']) ? trim($_POST['site_encode']) : "UTF-8";

if($site_name != "" && $site_url != "http://" && $site_url != "" && $site_sess != ""){
	$_SESSION['site_name'] = $site_name;
	$_SESSION['site_url'] = $site_url;
	$_SESSION['img_dir'] = $img_dir;
	$_SESSION['site_sess'] = $site_sess;
	$_SESSION['site_encode'] = $site_encode;

	$chk = true;
	$jump = "index4.php";
} else {

	if($site_name == "" || $site_name == "サイト名"){
		$mes .=  "サイト名が未入力です。<br >";
	}
	if($site_url == "" || $site_url == "http://"){
		$mes .=  "サイトURLが未入力です。<br >";
	}
	if($img_dir == ""){
		$mes .=  "イメージ保管場所が未入力です<br >";
	}
	if($site_sess == ""){
		$mes .=  "セッション名が未入力です。<br >";
	}
	$chk = false;
	$jump = "index3.php";
}

?>
<body>
<form id="setup" name="setup" method="post" action="<?php echo $jump ?>">
<table width="100%" border="0">
	<tr>
		<td height="362" valign="top">
		<div align="center">
		<p><img src="./images/cenote_logo.png" width="350" height="100" /></p>
		<p class="style1">～SETUP TOOL～</p>
		<p class="style1">２．サイトの基本定義</p>

		<table>
		<?php
		if(isset($_POST['Submit'])){
			if($_POST['Submit'] == "確認"){
				if($mes != ""){
					echo "<tr>";
					echo "<td colspan = \"2\"><span class=\"red\">";
					echo $mes;
					echo "</span></td>";
					echo "</tr>";
				}
			}
		}
		?>

		<?php
		if( $chk ){
			echo "<tr>
      			    <td class=\"style2\">サイト名</td>
			        <td class=\"style2\">$site_name</td>
 			       </tr>
 			       <tr>
   			        <td class=\"style2\">サイトURL</td>
  			        <td class=\"style2\">$site_url</td>
 			       </tr>
 			       <tr>
   			        <td class=\"style2\">イメージ保管場所</td>
  			        <td class=\"style2\">$img_dir</td>
  			       </tr>
  			       <tr>
   			        <td class=\"style2\">セッション名</td>
  			        <td class=\"style2\">$site_sess</td>
  			       </tr>
  			       <tr>
   			        <td class=\"style2\">WEB文字コード</td>
  			        <td class=\"style2\">$site_encode</td>
  			      </tr>
  			      <tr>";
			echo '<td colspan="2"><div align="center"><input name="Submit" type="submit" id="Submit" value="次へ" /></div>';
		} else {
			echo "<tr>
      			    <td class=\"style2\">サイト名</td>
			        <td class=\"style2\"><input name=\"site_name\" type=\"text\" id=\"site_name\" value=\"$site_name\" /></td>
 			       </tr>
 			       <tr>
   			        <td class=\"style2\">サイトURL</td>
  			        <td class=\"style2\"><input name=\"site_url\" type=\"text\" id=\"site_url\" size=\"45\" value=\"$site_url\" /></td>
 			       </tr>
 			       <tr>
   			        <td class=\"style2\">イメージ保管場所</td>
  			        <td class=\"style2\"><input name=\"img_dir\" type=\"text\" id=\"img_dir\" size=\"45\" value=\"$img_dir\" /></td>
 			       </tr>
 			       <tr>
   			        <td class=\"style2\">セッション名</td>
  			        <td class=\"style2\"><input name=\"site_sess\" type=\"text\" id=\"site_sess\" value=\"$site_sess\" /></td>
  			      </tr>
  			      <tr>
   			        <td class=\"style2\">WEB文字コード</td>
  			        <td class=\"style2\">
						<select name=\"site_encode\" id=\"site_encode\">
							<option value=\"UTF-8\" selected=\"selected\">UTF-8</option>
							<option value=\"EUC-JP\">EUC-JP</option>
							<option value=\"SHIFT-JIS\">SHIFT-JIS</option>
						</select></td>
  			      </tr>";
			echo '<td colspan="2"><div align="center"><input name="Submit" type="submit" id="Submit" value="確認" /></div>';
		}
		?>
			</td>
			</tr>
			<p>&nbsp;</p>
			</div>
			</td>
			</tr>
		</table>
		</form>

</body>
</html>

==> cenote_0.9.3_20071026.zip: cenote/setup/index3.php <==
<?php
if(file_exists("../configuration.php")){
	header("Location: ./index.php");
}
?>

<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<meta http-equiv="Content-Type" content="text/html; charset=UTF-8" />
<title>CENOTE SETUP TOOL(SITE CONFIGURATION)</title>
<style type="text/css">
<!--
body {
	margin-left: 0px;
	margin-top: 0px;
	margin-right: 0px;
	margin-bottom: 0px;
}
.style1 {
	font-size: 24px;
	font-style: italic;
	text-align: center;
}
.style2 {font-size: 14px; font-style: bold; text-align: left;}

.red {color: #FF0000}
table.con {
	border-style: solid;
    border-width: 1px;
    border-color: #666;
}

th.con {
	width:100%;
	height:21px;
	color: #EEE;
	background-color: #CCC;
	border-width: 1px;
	margin: 0px;
	padding: 0px;
	text-align:left;
	font-size: 12px;
	font-weight: bold;
}
td.con {
	height:25px;
	font-size: 12px;
	font-style: normal;
	margin: 0px;
	background-color: #DDD;
	border-width: 1px;
	padding: 1px;
	color: #000;
}

-->
</style>
</head>
<?php
session_name("CENOTE_SETUP");
session_cache_limiter('private, must-revalidate');
session_start();

$mes = "";

$site_name = isset($_POST['site_name']) ? trim($_POST['site_name']) : "";
$site_url  = isset($_POST['site_url']) ? trim($_POST['site_url']) : "http://";
$site_path = isset($_POST['site_path']) ? trim($_POST['site_path']) : "";
$site_sess = isset($_POST['site_sess']) ? trim($_POST['site_sess']) : "cenote";
$site_encode = isset($_POST['site_encode']) ? trim($_POST['site_encode']) : "UTF-8";

if($site_name != "" && $site_url != "http://" && $site_url != "" && $site_sess != ""){
	$_SESSION['site_name'] = $site_name;
	$_SESSION['site_url'] = $site_url;
	$_SESSION['site_path'] = $site_path;
	$_SESSION['site_sess'] = $site_sess;
	$_SESSION['site_encode'] = $site_encode;

	$chk = true;
	$jump = "index4.php";
} else {

	if($site_name == "" || $site_name == "サイト名"){
		$mes .=  "サイト名が未入力です。<br >";
	}
	if($site_url == "" || $site_url == "http://"){
		$mes .=  "サイトURLが未入力です。<br >";
	}
	if($site_sess == ""){
		$mes .=  "セッション名が未入力です。<br >";
	}
	$chk = false;
	$jump = "index3.php";
}

?>
<body>
<form id="setup" name="setup" method="post" action="<?php echo $jump ?>">
<table width="100%" border="0">
	<tr>
		<td height="362" valign="top">
		<div align="center">
		<p><img src="./images/cenote_logo.png" width="350" height="100" /></p>
		<p class="style1">～SETUP TOOL～</p>
		<p class="style1">２．サイトの基本定義</p>

		<table>
		<?php
		if(isset($_POST['Submit'])){
			if($_POST['Submit'] == "確認"){
				if($mes != ""){
					echo "<tr>";
					echo "<td colspan = \"2\"><span class=\"red\">";
					echo $mes;
					echo "</span></td>";
					echo "</tr>";
				}
			}
		}
		?>

		<?php
		if( $chk ){
			echo "<tr>
      			    <td class=\"con\" width=\"150\">サイト名</td>
			        <td class=\"con\" width=\"250\">$site_name</td>
 			       </tr>
 			       <tr>
   			        <td class=\"con\">サイトURL</td>
  			        <td class=\"con\">$site_url</td>
 			       </tr>
 			        <tr>
   			        <td class=\"con\">サイトPATH</td>
  			        <td class=\"con\">$site_path</td>
 			       </tr>
  			       <tr>
   			        <td class=\"con\">セッション名</td>
  			        <td class=\"con\">$site_sess</td>
  			       </tr>
  			       <tr>
   			        <td class=\"con\">WEB文字コード</td>
  			        <td class=\"con\">$site_encode</td>
  			      </tr>
  			      <tr>";
			echo '<td colspan="2"><div align="center"><input name="Submit" type="submit" id="Submit" value="次へ" /></div>';
		} else {
			echo "<tr>
      			    <td class=\"con\" width=\"150\">サイト名</td>
			        <td class=\"con\" width=\"250\"><input name=\"site_name\" type=\"text\" id=\"site_name\" value=\"$site_name\" /></td>
 			       </tr>
 			       <tr>
   			        <td class=\"con\">サイトURL</td>
  			        <td class=\"con\"><input name=\"site_url\" type=\"text\" id=\"site_url\" size=\"45\" value=\"$site_url\" /></td>
 			       </tr>
 			       <tr>
   			        <td class=\"con\">サイトPATH</td>
  			        <td class=\"con\"><input name=\"site_path\" type=\"text\" id=\"site_path\" size=\"45\" value=\"$site_path\" />
  			        <br />サイトのドキュメントルートからのパス(不明の場合は空白にしてください）</td>
 			       </tr>
 			       <tr>
   			        <td class=\"con\">セッション名</td>
  			        <td class=\"con\"><input name=\"site_sess\" type=\"text\" id=\"site_sess\" value=\"$site_sess\" /></td>
  			      </tr>
  			      <tr>
   			        <td class=\"con\">WEB文字コード</td>
  			        <td class=\"con\">
						<select name=\"site_encode\" id=\"site_encode\">
							<option value=\"UTF-8\" selected=\"selected\">UTF-8</option>
							<option value=\"EUC-JP\">EUC-JP</option>
							<option value=\"SHIFT-JIS\">SHIFT-JIS</option>
						</select></td>
  			      </tr>";
			echo '<td  class="con" colspan="2"><div align="center"><input name="Submit" type="submit" id="Submit" value="確認" /></div>';
		}
		?>
			</td>
			</tr>
			<p>&nbsp;</p>
			</div>
			</td>
			</tr>
		</table>
		</form>

</body>
</html>
